setBeta.HybridObj: Hybrid (hybrid approach)
Description
Default mutator of the field Beta of the object taken in an argument.
Usage
# S3 method for HybridObj
setBeta(rfo, beta)
Value
[Hybrid(1)]
Modified version of the object taken in the argument.
Arguments
- rfo
[Hybrid(1)]
Object of class Hybrid taken in the argument.
- beta
[vector(1)]
Index of binary/categorial variables.